@@ -515,7 +515,7 @@ class ProjectApps(Controller):
     def attach_certificate(self):
         project_id = self.app.pargs.project_id
         url = urllib3.util.parse_url(self.app.pargs.url)
-        url = (url.scheme or 'https://') + url.host
+        url = (url.scheme or 'https') + '://' + url.host
         fqdn = self.app.pargs.fqdn
 
         data = {'fqdn': fqdn, 'url': url}
